create or replace package body vv_htp
as
/**************************************************
||
||             Private Procedures
||
**************************************************/

   FUNCTION get_display_find return VARCHAR2
   IS
      l_disp_find       VARCHAR2 (40) := 'vvcs_incidents';  -- this is the default find page
      l_str             VARCHAR2 (40);
   BEGIN
      l_str := OWA_UTIL.get_procedure;
      -- Only Display the "New Search" if outside these "pages"
      IF OWA_UTIL.get_procedure IN ('ORACLEAPPS.RF'
                                   ,'VVCS_INCIDENTS','VVCS_INCIDENT_STATUS','VVCS_CALL_WRAP_UPS')
      THEN
         l_disp_find := NULL;
      END IF;

      RETURN l_disp_find;
   END;

   FUNCTION get_oracle_sid return VARCHAR2
   IS
      l_oracle_sid        VARCHAR2(40);
   BEGIN

      select value
        into l_oracle_sid
        from v$parameter
       where name = 'db_name';

       return l_oracle_sid;

    exception

     when others then
       return 'no_instance';

   END;
      
/**************************************************
||
||             Public Procedures
||
**************************************************/


   PROCEDURE cell_filler (p_width VARCHAR2 := 'width=2%')
   IS
   BEGIN
      HTP.tabledata (
         HTF.fontopen (0, 'Verdana', '2') || c_nbsp || HTF.fontclose,
         cattributes => p_width
      );
   END;

   PROCEDURE table_header (text IN VARCHAR2, p_attributes VARCHAR2 := '')
   IS
   BEGIN
      HTP.tabledata (
         HTF.fontopen ('white', 'Verdana', '2') ||
         HTF.strong (text) ||
         HTF.fontclose,
         cattributes => 'bgcolor="' ||
                        c_list_header_color ||
                        '" ' ||
                        p_attributes
      );
   END;

   PROCEDURE header_data (
      text           IN   VARCHAR2,
      p_color             VARCHAR2 := c_default_bg_color,
      p_attributes        VARCHAR2 := ''
   )
   IS
   BEGIN
      HTP.tabledata (
         HTF.fontopen (0, 'Verdana', '2') || text || HTF.fontclose,
         cattributes => 'bgcolor=' || p_color || ' ' || p_attributes
      );
   END;

   PROCEDURE sub_table_header (text IN VARCHAR2, p_attributes VARCHAR2 := '')
   IS
   BEGIN
      HTP.tabledata (
         HTF.fontopen ('white', 'Verdana', '1') ||
         HTF.strong (text) ||
         HTF.fontclose,
         cattributes => 'bgcolor="' ||
                        c_sub_list_header_color ||
                        '"' ||
                        p_attributes
      );
   END;

   PROCEDURE table_data (
      text           IN   VARCHAR2,
      p_color             VARCHAR2 := c_default_bg_color,
      p_attributes        VARCHAR2 := ''
   )
   IS
   BEGIN
      HTP.tabledata (
         HTF.fontopen (0, 'Verdana', '1') || text || HTF.fontclose,
         cattributes => 'bgcolor=' || p_color || ' ' || p_attributes
      );
   END;

   PROCEDURE create_blank_row (
      colspan_in   IN   VARCHAR2,
      msg_in       IN   VARCHAR2 := 'No Data Found'
   )
   IS
   BEGIN
      HTP.tabledata (
         '<b>' || msg_in || '</b>',
         cattributes => 'align="center" bgcolor="' ||
                        c_list_color1 ||
                        '" colspan="' ||
                        colspan_in ||
                        '"'
      );
   END create_blank_row;

   PROCEDURE create_msg (msg_text_in IN VARCHAR2)
   IS
   BEGIN
      HTP.tableopen ('width=100%');
      HTP.tablerowopen;
      HTP.tabledata (
         HTF.fontopen (ccolor => c_msg_color, cface => 'Verdana') ||
         '<b>' ||
         msg_text_in ||
         '</b>' ||
         HTF.fontclose,
         cattributes => 'align=center'
      );
      HTP.tablerowclose;
      HTP.tableclose;
   END create_msg;

   PROCEDURE create_footer
   IS
      l_disp_find       VARCHAR2 (40) := 'vvcs_incidents';
      v_language_code   VARCHAR2 (2) := 'US';
      l_session_id      NUMBER;
   BEGIN
      HTP.nl;


      HTP.tableopen (cattributes => 'width=99%');
      HTP.tablerowopen (calign => 'CENTER');
      htp.tabledata(htf.img('/media/shopnbc.jpg', cattributes=>'border=1'), cattributes=>'align=right');
      HTP.tablerowclose;
      HTP.tableclose;

      -- Get the "New Search" page
      l_disp_find := get_display_find;

      -- Verify we logged on through Oracle so we can display the standard toolbar
      IF (icx_sec.validatesession (c_validate_only => 'Y'))
      THEN
         -- l_session_id := to_number(icx_sec.getID(icx_sec.PV_SESSION_ID));
         -- htp.p('Session:'||l_session_id);
         -- c_user_id := icx_sec.getID(icx_sec.PV_USER_ID);

         icx_admin_sig.toolbar (
            language_code => 'US',
            disp_find => l_disp_find,
            disp_help => 'N',
            disp_mainmenu => 'Y'
         );
      ELSE
         HTP.tableopen (cattributes => 'width=100%');
         HTP.tablerowopen (calign => 'CENTER');

         -- do not show in HTML page since it's already the "New Search" window
         IF l_disp_find IS NOT NULL
         THEN
            HTP.tabledata (cattributes => 'WIDTH=30%');
            HTP.tabledata (
               HTF.anchor (
                  l_disp_find,
                  HTF.img (
                     '/media/FNDSFIND.gif',
                     'CENTER',
                     'New Search'
                  ),
                  '',
                  'onMouseOver="window.status=''New Search'';return true"'
               ),
               cattributes => 'WIDTH=40%'
            );
         END IF;

         -- Notice that this can and will be another TD from the previous IF
         -- We want this type of fall through
         HTP.tabledata (
            HTF.anchor (
               '/OA_HTML/US/ICXINDEX.htm',
               HTF.img (
                  '/media/FNDILOGN.gif',
                  'RIGHT',
                  'Oracle Login'
               ),
               '',
               'onMouseOver="window.status=''Oracle Login'';return true"'
            ),
            cattributes => 'WIDTH=30%'
         );
         HTP.tablerowclose;
         HTP.tablerowopen (calign => 'CENTER');

         -- do not show in HTML page since it's already the "New Search" window
         IF l_disp_find IS NOT NULL
         THEN
            HTP.tabledata;
            HTP.tabledata (
               cvalue => HTF.anchor (
                            curl => l_disp_find,
                            ctext => '<FONT SIZE=2 COLOR=#000000>' ||
                                     'New Search' ||
                                     '</FONT>',
                            cattributes => 'onMouseOver="window.status=''New Search'';return true"'
                         ),
               calign => 'CENTER'
            );
         END IF;

         -- Notice that this can and will be another TD from the previous IF
         -- We want this type of fall through
         HTP.tabledata (
            cvalue => HTF.anchor (
                         curl => '/OA_HTML/US/' || get_oracle_sid || '_web.htm',
                         ctext => '<FONT SIZE=2 COLOR=#000000>' ||
                                  'Oracle Login' ||
                                  '</FONT>',
                         cattributes => 'onMouseOver="window.status=''Oracle Login'';return true"'
                      ),
            calign => 'RIGHT'
         );
         HTP.tablerowclose;
         HTP.tableclose;
      END IF;
   END create_footer;

end; -- End of VV_HTP
/
show errors
