create or replace procedure VVCS_CALL_WRAP_UPS (expand_date       IN VARCHAR2 := NULL
                                              , expand_outcome_id IN number   := -1
                                              , expand_result_id  IN number   := -1
                                              , begin_date        IN VARCHAR2 := NULL
                                              , end_date          IN VARCHAR2 := NULL)
IS
--
-- VVCS_CALL_WRAP_UPS
--
-- Purpose: Display Statisticst About Call Wrap Up Codes
--
-- MODIFICATION HISTORY
-- Person     Date         Comments
-- ---------  -----------  -------------------------------------------       
-- J.Rimblas  28-JUN-2001  Creation

  l_incidents number;
  i           number;
  j           number;
  k           number;
  l_percent   number;
  l_msg            VARCHAR2 (300);
  l_cell_color     VARCHAR2 (20);
  l_expand         BOOLEAN := FALSE;
  l_expand_result  BOOLEAN := FALSE;

  l_last_date      date;

  l_begin_date     date;
  l_end_date       date;
 
  /*
     Exclude:
       10002	-- Request Processed
       10008	-- BROWSE RECORD
   */

  cursor outcome_cur (p_begin_date IN date
                    , p_end_date   IN date)
      IS
    select trunc(int.start_date_time) interaction_date
         , int.outcome_id
         , out.outcome_code
         , sum(int.duration) outcome_duration
         , count(*) total_outcomes
      from jtf_ih_interactions int
         , jtf_ih_outcomes_tl out
     where int.outcome_id = out.outcome_id(+)
       and out.outcome_id in (10005	-- SHIPPING and HANDLING ADJ
                            , 10019	-- 3RD PARTY SALES
                            , 10020	-- PRODUCT INFORMATION
                            , 10021	-- VENDOR INQUIRY - DROPSHIP
                            , 10023	-- RETURNS
                            , 10009	-- ORDER STATUS
                            , 10011	-- MEMBER REQUEST
                            , 10012	-- CANCEL ORDER
                            , 10013	-- INTERNET
                            , 10014	-- COMPUTER
                            , 10015	-- PRICE ADJUSTMENT
                            , 10016	-- DELIVERY CLAIMS
                            , 10017	-- AUCTION
                            , 10018	-- CONTINUITY PROGRAM
                            , 10003	-- TRANSFER
                            , 10004	-- CREDIT
                            )
       and out.source_lang = 'US'
       and int.start_date_time between p_begin_date and p_end_date + .99999
     group by trunc(int.start_date_time)
            , int.outcome_id
            , out.outcome_code
     order by 1, out.outcome_code;

  cursor results_cur (p_outcome_id IN number
                    , p_begin_date IN date
                    , p_end_date   IN date)
      IS
    select trunc(int.start_date_time) interaction_date
         , int.outcome_id
         , out.outcome_code
         , int.result_id
         , rsl.result_code
         , sum(int.duration) total_duration
         , count(*) total_results
      from jtf_ih_interactions int
         , jtf_ih_outcomes_tl out
         , jtf_ih_results_tl rsl
     where int.outcome_id = out.outcome_id(+)
       and int.result_id = rsl.result_id(+)
       and int.outcome_id = p_outcome_id
       and int.start_date_time between p_begin_date and p_end_date + .99999
     group by trunc(int.start_date_time)
            , int.outcome_id
            , out.outcome_code
            , int.result_id
            , rsl.result_code
     order by 1, rsl.result_code;

  cursor reasons_cur (p_outcome_id IN number
                    , p_result_id  IN number
                    , p_begin_date IN date
                    , p_end_date   IN date)
      IS
    select trunc(int.start_date_time) interaction_date
         , out.outcome_code
         , rsl.result_code
         , int.reason_id
         , rea.reason_code
         , sum(int.duration) total_duration
         , count(*) total_reasons
      from jtf_ih_interactions int
         , jtf_ih_outcomes_tl out
         , jtf_ih_results_tl rsl
         , jtf_ih_reasons_tl rea
     where int.outcome_id = out.outcome_id(+)
       and int.result_id = rsl.result_id(+)
       and int.reason_id = rea.reason_id(+)
       and int.outcome_id = p_outcome_id
       and int.result_id = p_result_id
       and int.start_date_time between p_begin_date and p_end_date + .99999
     group by trunc(int.start_date_time)
            , out.outcome_code
            , rsl.result_code
            , int.reason_id
            , rea.reason_code
     order by 1, rsl.result_code;

 
BEGIN

   htp.htmlOpen;

   -- This validate will make sure the user is logged in
   if icx_sec.validateSession then
   /*{*/

   htp.headopen;
   htp.Title('VV CS Wrap Ups Monitor');

   -- This is to try an avoid reload/refresh problems,
   -- However IE 4.01 still does not support this feature.
   htp.print('<META HTTP-EQUIV="Pragma" CONTENT="no-cache">');
 
   htp.headclose;
   htp.bodyOpen(vv_htp.C_DEFAULT_BG_COLOR,
           'link=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' alink=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' vlink=' || vv_htp.C_DEFAULT_BG_COLOR);

--    htp.tabledata(htf.img('/media/shopnbc.jpg'));
--  '<h2><font face="Arial">Customer Contact Information Center</font></h2>'

   htp.tableOpen('WIDTH=100%');
   htp.tableRowOpen;
      htp.tabledata(vv_htp.c_nbsp, CATTRIBUTES=>'width=70%');
      htp.tabledata(htf.CODE('Date: '||to_char(sysdate, 'DD-MON-YYYY')) || '<br>'
                 || htf.CODE('Time: '|| to_char(sysdate, 'HH24:MI:SS')  || ' CST')
                , CATTRIBUTES=>'WIDTH=20% valign=top');
   htp.tableRowClose;
   htp.tableClose;

   htp.br;

   -- Set the default dates
   l_msg := '';
   if begin_date is null then
      l_begin_date := trunc(sysdate);
   else
      begin
        l_begin_date := to_date(begin_date, 'DD-MON-YYYY');
        exception
        when others then
           l_msg := '<br><font color="red" face="Verdana" size=3>[' || begin_date || '] is an invalid date</font><br>';
           l_begin_date := trunc(sysdate);
      end;
   end if;

   if end_date is null then
      l_end_date := trunc(sysdate);
   else
      begin
        l_end_date := to_date(end_date, 'DD-MON-YYYY');
        exception
        when others then
           l_msg := l_msg || '<br><font color="red" face="Verdana" size=3>[' || end_date || '] is an invalid date</font><br>';
           l_end_date := trunc(sysdate);
      end;
   end if;

   -- # of Days to Display
   i:=l_end_date - l_begin_date;
   if i=0 then
     if l_begin_date = trunc(sysdate) then
       l_msg := l_msg || '(<b>Today</b>)';
     end if;
   else
     l_msg := l_msg || '(Last ' || to_char(i+1) || ' days)';
   end if;

   htp.formopen('vvcs_call_wrap_ups', 'GET');

   htp.tableopen;
   htp.tablerowopen;
   htp.print('<td>');

   htp.fontopen(0, 'Arial,Verdana',4);
     htp.strong(vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp
             || 'Call Wrap-Up Codes');
   htp.fontclose;
   htp.fontopen(0, 'Verdana',2);
   htp.print(vv_htp.c_nbsp || l_msg);
   htp.fontclose;

   htp.print('</td>');
   htp.print('<td>');

/*
     if expand_date is not null then
        htp.formhidden('expand_date', expand_date);
     end if;
     if expand_outcome_id is not null then
        htp.formhidden('expand_outcome_id', expand_outcome_id);
     end if;
*/
     htp.fontopen(0, 'Arial,Verdana',2);
     htp.print(vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp
            || 'Range:');
     htp.formtext('begin_date', '11', '12', to_char(l_begin_date, 'DD-MON-YYYY'));
     htp.print('-');
     htp.formtext('end_date',   '11', '12', to_char(l_end_date, 'DD-MON-YYYY'));
     htp.fontclose;

     htp.formsubmit;


   htp.print('</td>');
   htp.tablerowclose;
   htp.tableclose;

   htp.formclose;

   HTP.tableopen ('width=70%');
   HTP.tablerowopen;
    vv_htp.cell_filler('width=2%');
    vv_htp.table_header('Date');
    vv_htp.table_header('Outcome');
    vv_htp.table_header('Total',    'align=right');
   HTP.tablerowclose;

   -- Init l_last_date with something very old so we never match on first pass
   l_last_date := to_date('01-JAN-1900');

   i:=0;
   FOR outcome_rec IN outcome_cur(l_begin_date, l_end_date)
   LOOP
       IF MOD (i, 2) = 0 THEN
            l_cell_color := vv_htp.c_list_color1;
       ELSE
            l_cell_color := vv_htp.c_list_color2;
       END IF;

       i := i + 1;

       if to_char(outcome_rec.interaction_date, 'DD-MON-YYYY') = expand_date and
          outcome_rec.outcome_id = expand_outcome_id
       then
          l_expand:= true;
       else
          l_expand:= false;
       end if;

       if l_last_date <> outcome_rec.interaction_date then

         htp.tablerowopen;
           vv_htp.cell_filler('');
           vv_htp.table_header(to_char(outcome_rec.interaction_date, 'DD-MON-YYYY'), 'width="22%"');
           vv_htp.cell_filler('colspan=2');
--         vv_htp.table_data(to_char(outcome_rec.interaction_date, 'DD-MON-YYYY'),  l_cell_color, 'colspan=3');
--         htp.print('<td colspan=2>' || vv_htp.c_nbsp || '</td>');
         htp.tablerowclose;
         l_last_date := outcome_rec.interaction_date;

       end if;

       HTP.tablerowopen;
         vv_htp.cell_filler('');
         if l_expand then
            htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
            || 'vvcs_call_wrap_ups?begin_date='  || to_char(l_begin_date, 'DD-MON-YYYY')
                    || chr(38) || 'end_date='    || to_char(l_end_date, 'DD-MON-YYYY'),
            htf.img('/media/aftreeop.gif'), 'current'   -- Display TAG
            ), CATTRIBUTES=>'align=right');
--          ), CATTRIBUTES=>'bgcolor=' || vv_htp.C_DEFAULT_BG_COLOR || ' align=center');
         else
            htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
            || 'vvcs_call_wrap_ups?expand_outcome_id=' || outcome_rec.outcome_id
                    || chr(38) || 'expand_date=' || to_char(outcome_rec.interaction_date, 'DD-MON-YYYY')
                    || chr(38) || 'begin_date='  || to_char(l_begin_date, 'DD-MON-YYYY')
                    || chr(38) || 'end_date='    || to_char(l_end_date, 'DD-MON-YYYY')
            || '#current',
            htf.img('/media/aftreecl.gif')
            ), CATTRIBUTES=>'align=right');
--          ), CATTRIBUTES=>'bgcolor=' || vv_htp.C_DEFAULT_BG_COLOR || ' align=center');
         end if;

--      vv_htp.table_data(to_char(outcome_rec.interaction_date, 'DD-MON-YYYY'),  l_cell_color);
        vv_htp.table_data(outcome_rec.outcome_code,     l_cell_color);
        vv_htp.table_data(outcome_rec.total_outcomes,   l_cell_color, 'align=right');
       HTP.tablerowclose;

       if l_expand then
       /*{*/
          HTP.tablerowopen;
          htp.print('<td colspan=4>');

             HTP.tableopen ('width=100%');
             HTP.tablerowopen;
              vv_htp.cell_filler('width=4%');
              vv_htp.cell_filler('width=25%');
              vv_htp.sub_table_header('Result');
              vv_htp.sub_table_header('Results',  'align=right');
              vv_htp.sub_table_header('% of Total','align=right');
             HTP.tablerowclose;

             j:=0;
             for results_rec in results_cur(outcome_rec.outcome_id
                                          , outcome_rec.interaction_date
                                          , outcome_rec.interaction_date) loop
                if mod(j,2) = 0 then
                   l_cell_color := vv_htp.C_SUB_LIST_COLOR1;
                else
                   l_cell_color := vv_htp.C_SUB_LIST_COLOR2;
                end if;

                if to_char(outcome_rec.interaction_date, 'DD-MON-YYYY') = expand_date and
                   results_rec.result_id = expand_result_id and
                   outcome_rec.outcome_id = expand_outcome_id
                then
                   l_expand_result:= true;
                else
                   l_expand_result:= false;
                end if;

                -- Calculate Percent
                if outcome_rec.total_outcomes <> 0 then
                  l_percent:=(results_rec.total_results * 100) / outcome_rec.total_outcomes;
                else
                  l_percent:=0;
                end if;

                j:=j+1;
                htp.tableRowOpen;
                   vv_htp.cell_filler();

                   if l_expand_result then
                      htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
                      || 'vvcs_call_wrap_ups?expand_date=' || to_char(outcome_rec.interaction_date, 'DD-MON-YYYY')
                              || chr(38) || 'begin_date='  || to_char(l_begin_date, 'DD-MON-YYYY')
                              || chr(38) || 'end_date='    || to_char(l_end_date, 'DD-MON-YYYY')
                              || chr(38) || 'expand_outcome_id=' || expand_outcome_id,
                      htf.img('/media/aftreeop.gif'), 'current'   -- Display TAG
                      ), CATTRIBUTES=>'align=right');
                   else
                      htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
                      || 'vvcs_call_wrap_ups?expand_date=' || to_char(outcome_rec.interaction_date, 'DD-MON-YYYY')
                              || chr(38) || 'begin_date='  || to_char(l_begin_date, 'DD-MON-YYYY')
                              || chr(38) || 'end_date='    || to_char(l_end_date, 'DD-MON-YYYY')
                              || chr(38) || 'expand_outcome_id=' || expand_outcome_id
                              || chr(38) || 'expand_result_id='  || results_rec.result_id 
                      || '#current',
                      htf.img('/media/aftreecl.gif')
                      ), CATTRIBUTES=>'align=right');
                   end if;

                   vv_htp.table_data(results_rec.result_code,  l_cell_color);
                   vv_htp.table_data(results_rec.total_results, l_cell_color, 'align=right');
                   vv_htp.table_data(to_char(l_percent, '999.0'),  l_cell_color, 'align=right');
                htp.tableRowClose;

                if l_expand_result then
                /*{*/
                   HTP.tablerowopen;
                   htp.print('<td colspan=5>');

                     HTP.tableopen ('width=100%');
                     HTP.tablerowopen;
                       vv_htp.cell_filler('width=33%');
                       vv_htp.sub_table_header('Reason Code');
                       vv_htp.sub_table_header('Reasons', 'align=right');
--                     vv_htp.sub_table_header('% of Total','align=right');
--                     vv_htp.cell_filler('width=4%');
                     HTP.tablerowclose;

                     k:=0;
                     for reasons_rec in reasons_cur(results_rec.outcome_id
                                                  , results_rec.result_id
                                                  , results_rec.interaction_date
                                                  , results_rec.interaction_date) loop
                     /*{*/
                         if mod(k,2) = 0 then
                            l_cell_color := vv_htp.C_SUB_LIST_COLOR1;
                         else
                            l_cell_color := vv_htp.C_SUB_LIST_COLOR2;
                         end if;

                         k:=k+1;
                         htp.tableRowOpen;
                            vv_htp.cell_filler();
                            vv_htp.table_data(reasons_rec.reason_code,  l_cell_color);
                            vv_htp.table_data(reasons_rec.total_reasons, l_cell_color, 'align=right');
--                          vv_htp.cell_filler();
--                          vv_htp.cell_filler();
                         htp.tableRowClose;
                     /*}*/
                     end loop;
                     htp.tableClose;

                  htp.print('</td>');
                  HTP.tablerowclose;

                /*}*/
                end if; -- l_expand_result 


             end loop;

             IF j = 0 THEN
                vv_htp.cell_filler('');
                -- Make sure to use the number of columns displayed
                vv_htp.table_data('<b>No Incident Types Found</b>', vv_htp.C_SUB_LIST_COLOR1 , ' align="center" bgcolor="'
	                || '" colspan="4"');
             END IF;

             htp.tableClose;

          htp.print('</td>');
          HTP.tablerowclose;
       /*}*/
       end if;  -- l_expand

   end loop;

   if i = 0 then
      vv_htp.cell_filler('');
      vv_htp.create_blank_row ('5');
   end if;  

   HTP.tableclose;
  
   htp.br; 
   htp.br; 

   vv_htp.create_footer;

   HTP.bodyclose;

   end if;  -- sessionValidate
   /*}*/
   HTP.htmlclose;

END; -- Procedure VVCS_INCIDENTS
/
show errors
exit
