create or replace procedure VVCS_INCIDENT_NOTES (begin_date        IN VARCHAR2 := NULL
                                               , end_date          IN VARCHAR2 := NULL
                                               , incident_type_id  IN number   := -1
                                               , owner_id          IN number   := -1)
IS
--
-- VVCS_INCIDENT_NOTES
--
-- Purpose: Display Incidents with Notes
--
-- MODIFICATION HISTORY
-- Person     Date         Comments
-- ---------  -----------  -------------------------------------------       
-- J.Rimblas  06-JUL-2001  Creation

  l_incidents number;
  i           number;
  l_msg            VARCHAR2 (300);
  l_cell_color     VARCHAR2 (20);

  l_begin_date     date;
  l_end_date       date;
 
  cursor incidents_cur (p_begin_date       IN date
                      , p_end_date         IN date
                      , p_incident_type_id IN number
                      , p_owner_id         IN number)
      IS
     select inc.incident_id
          , inc.incident_number
          , inc.incident_date
          , status.name  status
          , inc.incident_type_id
          , types.name incident_type
          , inc.problem_code
          , account.account_number account
          , party.party_name customer_name
          , party_cont.phone_area_code || '-' || party_cont.phone_number phone
          , fnd.user_name logged_by
          , replace(nvl(note.note, vv_htp.c_nbsp) , chr(10) , '<br>') note
       from FND_USER fnd
          , JTF_PARTIES_ALL_V party
          , CSC_HZ_PARTIES_SELF_V sr_party
          , CS_SR_KB_NOTE_LINKS_V note
          , HZ_CONTACT_POINTS party_cont
          , CS_HZ_SR_CONTACT_POINTS sr_cont
          , JTF_CUST_ACCOUNTS_ALL_V account
          , CS_INCIDENT_TYPES_TL types
          , CS_INCIDENT_STATUSES_TL STATUS
          , CS_INCIDENTS_ALL_B inc
      where inc.incident_status_id (+) = status.incident_status_id
        and inc.incident_type_id = types.incident_type_id
        and inc.incident_id = note.app_obj_id (+)
        and inc.account_id = account.cust_account_id (+)
        and fnd.user_id = inc.created_by
        and inc.incident_status_id = 1 -- OPEN
        and inc.incident_type_id = p_incident_type_id   -- 1 = $ ADJUSTMENTS, 22 = VENDOR INQUIRY-DROP SHIP
        and inc.incident_owner_id = p_owner_id
        and note.note_type_code (+) = 'CS_PROBLEM'
        and note.app_obj_code (+) = 'SR'
        and inc.customer_id = party.party_id (+)
        and inc.incident_id = sr_cont.incident_id (+)
        and sr_cont.party_id = sr_party.party_id (+)
        and sr_cont.contact_point_id = party_cont.contact_point_id (+)
        and sr_cont.primary_flag (+) = 'Y'
        and inc.incident_date >= p_begin_date
      order by inc.problem_code, inc.incident_date, inc.incident_number;

  cursor incident_types_cur
      IS
     select type.incident_type_id
          , nvl(type.name, types.name) incident_type
       from CS_INCIDENT_TYPES_B type
          , CS_INCIDENT_TYPES_TL types
      where types.incident_type_id = type.incident_type_id
        and sysdate between nvl(type.start_date_active, sysdate-1) and nvl(type.end_date_active, sysdate + 1)
      order by type.incident_type_id;

  cursor owners_cur
      IS
    select o.resource_id owner_id
         , o.resource_name owner
      from CS_SR_OWNERS_SEARCH_V O
     where o.resource_type = 'RS_TEAM'
     order by o.resource_name;

BEGIN

   htp.htmlOpen;

   -- This validate will make sure the user is logged in
   if icx_sec.validateSession then
   /*{*/

   htp.headopen;
   htp.Title('VV Incident Notes');

   -- This is to try an avoid reload/refresh problems,
   -- However IE 4.01 still does not support this feature.
   htp.print('<META HTTP-EQUIV="Pragma" CONTENT="no-cache">');
 
   htp.headclose;
   htp.bodyOpen(vv_htp.C_DEFAULT_BG_COLOR,
           'link=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' alink=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' vlink=' || vv_htp.C_DEFAULT_BG_COLOR);

--    htp.tabledata(htf.img('/media/shopnbc.jpg'));
--  '<h2><font face="Arial">Customer Contact Information Center</font></h2>'

   htp.tableOpen('WIDTH=100%');
   htp.tableRowOpen;
      htp.tabledata(vv_htp.c_nbsp, CATTRIBUTES=>'width=70%');
      htp.tabledata(htf.CODE('Date: '||to_char(sysdate, 'DD-MON-YYYY')) || '<br>'
                 || htf.CODE('Time: '|| to_char(sysdate, 'HH24:MI:SS')  || ' CST')
                , CATTRIBUTES=>'WIDTH=20% valign=top');
   htp.tableRowClose;
   htp.tableClose;

   htp.br;

   -- Set the default dates
   l_msg := '';
   if begin_date is null then
      l_begin_date := trunc(sysdate);
   else
      begin
        l_begin_date := to_date(begin_date, 'DD-MON-YYYY');
        exception
        when others then
           l_msg := '<br><font color="red" face="Verdana" size=3>[' || begin_date || '] is an invalid date</font><br>';
           l_begin_date := trunc(sysdate);
      end;
   end if;

   if end_date is null then
      l_end_date := trunc(sysdate);
   else
      begin
        l_end_date := to_date(end_date, 'DD-MON-YYYY');
        exception
        when others then
           l_msg := l_msg || '<br><font color="red" face="Verdana" size=3>[' || end_date || '] is an invalid date</font><br>';
           l_end_date := trunc(sysdate);
      end;
   end if;

   -- # of Days to Display
   i:=l_end_date - l_begin_date;
   if i=0 then
     if l_begin_date = trunc(sysdate) then
       l_msg := l_msg || '(<b>Today</b>)';
     end if;
   else
     l_msg := l_msg || '(Last ' || to_char(i+1) || ' days)';
   end if;

   htp.formopen('vvcs_incident_notes', 'GET');

   htp.fontopen(0, 'Arial,Verdana',4);
     htp.strong(vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp
             || 'Incidents');
   htp.fontclose;
   htp.fontopen(0, 'Verdana',2);
   htp.print(vv_htp.c_nbsp || l_msg);
   htp.fontclose;

   htp.nl;

     htp.fontopen(0, 'Arial,Verdana',2);
     htp.print(vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp
            || 'Range:');
     htp.formtext('begin_date', '11', '12', to_char(l_begin_date, 'DD-MON-YYYY'));
     htp.print('-');
     htp.formtext('end_date',   '11', '12', to_char(l_end_date, 'DD-MON-YYYY'));


     htp.print(vv_htp.c_nbsp || 'Team:');

       if owner_id = -1 then
         l_msg:='SELECTED';
       else
         l_msg:='';
       end if;

     htp.formSelectOpen('owner_id');
     htp.formSelectOption('- Owner -' || '</OPTION>',  l_msg, 'VALUE=-1');

     for owner_rec IN owners_cur
     loop

       if owner_rec.owner_id = owner_id then
         l_msg:='SELECTED';
       else
         l_msg:='';
       end if;
       htp.formSelectOption(owner_rec.owner || '</OPTION>', l_msg
                          , 'VALUE=' || owner_rec.owner_id);
     end loop;


     htp.formSelectClose;

     htp.print(vv_htp.c_nbsp || 'Incident Type:');

       if incident_type_id = -1 then
         l_msg:='SELECTED';
       else
         l_msg:='';
       end if;

     htp.formSelectOpen('incident_type_id');
     htp.formSelectOption('- Choose a Type -' || '</OPTION>',  l_msg, 'VALUE=-1');

     for incident_type_rec IN incident_types_cur
     loop

       if incident_type_rec.incident_type_id = incident_type_id then
         l_msg:='SELECTED';
       else
         l_msg:='';
       end if;
       htp.formSelectOption(incident_type_rec.incident_type || '</OPTION>', l_msg
                          , 'VALUE=' || incident_type_rec.incident_type_id);
     end loop;

     htp.formSelectClose;

     htp.fontclose;

     htp.formsubmit;

   htp.formclose;

   HTP.tableopen ('width=100%');
   HTP.tablerowopen;
    vv_htp.table_header('Inc#');
    vv_htp.table_header('Inc' || vv_htp.c_nbsp || 'Date');
    vv_htp.table_header('Status');
--  vv_htp.table_header('Inc. Type');
    vv_htp.table_header('Problem Code');
    vv_htp.table_header('Account');
    vv_htp.table_header('Customer');
    vv_htp.table_header('Phone');
    vv_htp.table_header('Logged By');
    vv_htp.table_header('Note');
   HTP.tablerowclose;

   i:=0;
   FOR incidents_rec IN incidents_cur(l_begin_date, l_end_date, incident_type_id, owner_id)
   LOOP
     if incidents_rec.incident_date between l_begin_date and l_end_date + .99999 then
       IF MOD (i, 2) = 0 THEN
            l_cell_color := vv_htp.c_list_color1;
       ELSE
            l_cell_color := vv_htp.c_list_color2;
       END IF;

       i := i + 1;

       htp.tablerowopen;
        vv_htp.table_data(incidents_rec.incident_number, l_cell_color, 'valign=top');
        vv_htp.table_data(to_char(incidents_rec.incident_date, 'DD-MON-YY'),  l_cell_color, 'valign=top');
        vv_htp.table_data(incidents_rec.status,          l_cell_color, 'valign=top');
--      vv_htp.table_data(incidents_rec.incident_type,   l_cell_color, 'valign=top');
        vv_htp.table_data(incidents_rec.problem_code,    l_cell_color, 'valign=top');
        vv_htp.table_data(incidents_rec.account,         l_cell_color, 'valign=top');
        vv_htp.table_data(incidents_rec.customer_name,   l_cell_color, 'valign=top');
        vv_htp.table_data(incidents_rec.phone,           l_cell_color, 'valign=top');
        vv_htp.table_data(incidents_rec.logged_by,       l_cell_color, 'valign=top');
        vv_htp.table_data(incidents_rec.note,            l_cell_color, 'valign=top');
       HTP.tablerowclose;

     end if;

   end loop;

   if i = 0 then
      vv_htp.create_blank_row ('10');
   end if;  

   HTP.tableclose;
  
   htp.br; 
   htp.br; 

   vv_htp.create_footer;

   HTP.bodyclose;

   /*}*/
   end if;  -- validateSession

   HTP.htmlclose;

END; -- Procedure VVCS_INCIDENT_NOTES
/
show errors
exit
