create or replace procedure VVCS_INCIDENT_STATUS (expand_status_id IN number :=-1)
IS
--
-- VVCS_INCIDENT_STATUS
--
-- Purpose: Display Status Statisticst About Incidents
--
-- MODIFICATION HISTORY
-- Person     Date         Comments
-- ---------  -----------  -------------------------------------------       
-- J.Rimblas  24-MAY-2001  Creation

  i             number;
  j             number;
  l_expand      BOOLEAN := FALSE;
  l_status      BOOLEAN := FALSE;
  l_cell_color  VARCHAR2 (20);

  -- Don't include status 2 = CLOSED
  cursor inc_status_cur
      IS
    select inc.incident_status_id
         , status.name, count(*) total
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), -1, -1)) tomorrow
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 0, 0)) today
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 1, 1)) one_day
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 2, 2)) two_day
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 3, 3)) three_day
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 4, 1000)) four_day
      from CS_INCIDENTS_ALL_B inc
         , CS_INCIDENT_STATUSES_TL STATUS
     where inc.incident_status_id (+) = status.incident_status_id
       and status.language = (select userenv('lang') from dual)
       and status.incident_status_id in (1     -- OPEN
                                       , 102   -- PENDING CUSTOMER
                                       , 103   -- PENDING INTERNAL
                                       , 104   -- PENDING VENDOR
                                       , 106   -- IN PROCESS
                                       , 120   -- CORRECTION NEEDED
                                       , 121   -- ACTION COMPLETE BY WHSE/RETURN
                                       , 122   -- PLEASE CALL CUSTOMER
                                       , 123   -- FORWARDED TO LEGAL
                                       )
     group by inc.incident_status_id, name;

  cursor inc_owners_cur(l_incident_status_id_in number)
      IS
    select inc.incident_status_id
         , inc.incident_owner_id
         , o.resource_name owner
         , status.name, count(*) total
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), -1, -1)) tomorrow
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 0, 0)) today
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 1, 1)) one_day
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 2, 2)) two_day
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 3, 3)) three_day
         , sum(vvcs_is_status_due(trunc(sysdate) - trunc(EXPECTED_RESOLUTION_DATE), 4, 1000)) four_day
      from CS_INCIDENTS_ALL_B inc
         , CS_SR_OWNERS_SEARCH_V O
         , CS_INCIDENT_STATUSES_TL STATUS
     where inc.incident_status_id (+) = status.incident_status_id
       and status.language = (select userenv('lang') from dual)
       and status.incident_status_id = l_incident_status_id_in
       and inc.incident_owner_id = o.resource_id
     group by inc.incident_status_id, name
            , inc.incident_owner_id
            , o.resource_name;

BEGIN


   htp.htmlOpen;

   -- This validate will make sure the user is logged in
   if icx_sec.validateSession then
   /*{*/

   htp.headopen;
   htp.Title('VVCS Incident Status');

   htp.headclose;
   htp.bodyOpen(vv_htp.C_DEFAULT_BG_COLOR,
           'link=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' alink=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' vlink=' || vv_htp.C_DEFAULT_BG_COLOR);

   htp.fontopen(0, 'Arial,Verdana',4);
     htp.strong('Service Requests Status Summary');
   htp.fontclose;

   htp.br;

   htp.print('<center>');

   HTP.tableopen ('width=100%');
   HTP.tablerowopen;
    vv_htp.cell_filler('');
    vv_htp.cell_filler('width=10%');
    vv_htp.cell_filler('');
    vv_htp.cell_filler('');
    vv_htp.table_header('Due',           'align=center colspan=2');
    vv_htp.table_header('Past Due Days', 'align=center colspan=4');
   HTP.tablerowclose;
   HTP.tablerowopen;
    vv_htp.cell_filler('width=2%');
    vv_htp.table_header('Status','colspan=2');
    vv_htp.table_header('Total', 'align=right width=8%');
    vv_htp.table_header('Tomrw',    'align=right width=8%');
    vv_htp.table_header('Today', 'align=center width=8%');
    vv_htp.table_header('1', 'align=right width=8%');
    vv_htp.table_header('2', 'align=right width=8%');
    vv_htp.table_header('3', 'align=right width=8%');
    vv_htp.table_header('+4', 'align=right width=8%');
   HTP.tablerowclose;

   i:=0;
   FOR inc_status_rec IN inc_status_cur
   LOOP
       IF MOD (i, 2) = 0 THEN
            l_cell_color := vv_htp.c_list_color1;
       ELSE
            l_cell_color := vv_htp.c_list_color2;
       END IF;

       i := i + 1;

       if inc_status_rec.incident_status_id = expand_status_id then
          l_expand:= true;
       else
          l_expand:= false;
       end if;

       HTP.tablerowopen;

         if l_expand then
            htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
            || 'vvcs_incident_status',
            htf.img('/media/aftreeop.gif'), 'current'   -- Display TAG
            ), CATTRIBUTES=>'align=center');
--          ), CATTRIBUTES=>'bgcolor=' || vv_htp.C_DEFAULT_BG_COLOR || ' align=center');
         else
            htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
            || 'vvcs_incident_status?expand_status_id=' || to_char(inc_status_rec.incident_status_id)
            || '#current',
            htf.img('/media/aftreecl.gif')
            ), CATTRIBUTES=>'align=center');
--          ), CATTRIBUTES=>'bgcolor=' || vv_htp.C_DEFAULT_BG_COLOR || ' align=center');
         end if;

         vv_htp.table_data(inc_status_rec.name,  l_cell_color, 'colspan=2');
         vv_htp.table_data(inc_status_rec.total, l_cell_color, 'align=right');
         vv_htp.table_data(inc_status_rec.tomorrow, l_cell_color, 'align=right');
         vv_htp.table_data(inc_status_rec.today, l_cell_color, 'align=right');
         vv_htp.table_data(inc_status_rec.one_day, l_cell_color, 'align=right');
         vv_htp.table_data(inc_status_rec.two_day, l_cell_color, 'align=right');
         vv_htp.table_data(inc_status_rec.three_day, l_cell_color, 'align=right');
         vv_htp.table_data(inc_status_rec.four_day, l_cell_color, 'align=right');
       HTP.tablerowclose;

       if l_expand then
          HTP.tablerowopen;

             j:=0;
             for inc_owners_rec in inc_owners_cur(inc_status_rec.incident_status_id) loop

                if mod(j,2) = 0 then
                   l_cell_color := vv_htp.C_SUB_LIST_COLOR1;
                else
                   l_cell_color := vv_htp.C_SUB_LIST_COLOR2;
                end if;

                j:=j+1;
                htp.tableRowOpen;
                   vv_htp.cell_filler;
                   vv_htp.cell_filler;

                   vv_htp.table_data(inc_owners_rec.owner, l_cell_color);
                   vv_htp.table_data(inc_owners_rec.total, l_cell_color, 'align=right');
                   vv_htp.table_data(inc_owners_rec.tomorrow, l_cell_color, 'align=right');
                   vv_htp.table_data(inc_owners_rec.today, l_cell_color, 'align=right');
                   vv_htp.table_data(inc_owners_rec.one_day, l_cell_color, 'align=right');
                   vv_htp.table_data(inc_owners_rec.two_day, l_cell_color, 'align=right');
                   vv_htp.table_data(inc_owners_rec.three_day, l_cell_color, 'align=right');
                   vv_htp.table_data(inc_owners_rec.four_day, l_cell_color, 'align=right');
                htp.tableRowClose;

             end loop;

             htp.tableRowClose;
       end if;

   end loop;

   HTP.tableclose;
   htp.print('</center>');

   htp.br; 

   vv_htp.create_footer;

   HTP.bodyclose;

   end if;  -- sessionValidate
   /*}*/
   HTP.htmlclose; 

END; -- Procedure VVCS_INCIDENT_STATUS
/
show errors
