create or replace procedure VVCS_INCIDENTS (expand_date IN VARCHAR2 := NULL
                                          , expand_type_id IN number := -1)
IS
--
-- VVCS_INCIDENTS
--
-- Purpose: Display Statisticst About Incidents
--
-- MODIFICATION HISTORY
-- Person     Date         Comments
-- ---------  -----------  -------------------------------------------       
-- J.Rimblas  21-MAY-2001  Creation

  c_refresh_seconds  CONSTANT  varchar2(3) := '90';

  l_incidents number;
  i           number;
  j           number;
  k           number;
  l_percent   number;
  l_refresh_msg    VARCHAR2 (100);
  l_cell_color     VARCHAR2 (20);
  l_expand         BOOLEAN := FALSE;
  l_expand_type    BOOLEAN := FALSE;

  cursor incidents_cur
      IS
    select trunc(incident_date) incident_date, count(*) incidents
      from CS_INCIDENTS_ALL_B
     where incident_date >= trunc(sysdate-7)
     group by trunc(incident_date);

  cursor incident_types_cur (l_incident_date_in date)
  IS
    select inc.incident_type_id, types.name incident_type, count(*) incident_types
      from CS_INCIDENT_TYPES_TL types
         , CS_INCIDENTS_ALL_B inc
     where inc.incident_type_id = types.incident_type_id
       and inc.incident_date between l_incident_date_in and l_incident_date_in + .99999
     group by inc.incident_type_id, types.name
     order by 2;

  cursor inc_problem_codes_cur (l_incident_date_in date
                              , l_incident_type_id_in CS_INCIDENT_TYPES_TL.INCIDENT_TYPE_ID%TYPE)
  IS
    select inc.problem_code, count(*) problem_codes
      from CS_INCIDENTS_ALL_B inc
     where inc.incident_type_id = l_incident_type_id_in
       and inc.incident_date between l_incident_date_in and l_incident_date_in + .99999
     group by inc.problem_code
     order by 1;

 /*
   select trunc(creation_date) creation, count(incident_id) incidents
     from cs_sr_search_v
    where creation_date > to_date('18-MAY-2001', 'DD-MON-YYYY')
    group by trunc(creation_date);
 */
           
BEGIN

   htp.htmlOpen;

   -- This validate will make sure the user is logged in
   if icx_sec.validateSession then
   /*{*/

   htp.headopen;
   htp.Title('VV CS Incidents Monitor');

   -- Only refresh when 3rd drill down is closed
   if expand_type_id = -1 then
     -- Reload/Refresh the screen every n seconds
     htp.print('<META http-equiv="Refresh" content=' || c_refresh_seconds || '>');
     l_refresh_msg:='NOTE: This page reloads every ' || c_refresh_seconds || ' seconds.';
   else
     l_refresh_msg:='Refresh is suspended until Problem Code drill down closes';
   end if;

   -- This is to try an avoid reload/refresh problems,
   -- However IE 4.01 still does not support this feature.
   htp.print('<META HTTP-EQUIV="Pragma" CONTENT="no-cache">');
 
   htp.headclose;
   htp.bodyOpen(vv_htp.C_DEFAULT_BG_COLOR,
           'link=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' alink=' || vv_htp.C_DEFAULT_BG_COLOR
                   || ' vlink=' || vv_htp.C_DEFAULT_BG_COLOR);

--    htp.tabledata(htf.img('/media/shopnbc.jpg'));
--  '<h2><font face="Arial">Customer Contact Information Center</font></h2>'

   htp.tableOpen('WIDTH=100%');
   htp.tableRowOpen;
      htp.tabledata(vv_htp.c_nbsp, CATTRIBUTES=>'width=30%');
      htp.tabledata(htf.fontopen (0, 'Verdana', '1')
                 || l_refresh_msg
                 || htf.fontclose
               , CATTRIBUTES=>'align=left WIDTH=50%');
     htp.tabledata(htf.CODE('Date: '||to_char(sysdate, 'DD-MON-YYYY')) || '<br>'
                || htf.CODE('Time: '|| to_char(sysdate, 'HH24:MI:SS')  || ' CST')
               , CATTRIBUTES=>'WIDTH=20% valign=top');
   htp.tableRowClose;
   htp.tableClose;

   htp.br;

   htp.fontopen(0, 'Arial,Verdana',4);
     htp.strong(vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp || vv_htp.c_nbsp
             || 'Daily Service Requests');
   htp.fontclose;
   htp.fontopen(0, 'Verdana',2);
   htp.print(vv_htp.c_nbsp || '(Last 7 days)');
   htp.fontclose;
   htp.br;

   HTP.tableopen ('width=50%');
   HTP.tablerowopen;
    vv_htp.cell_filler('width=2%');
    vv_htp.table_header('Date');
    vv_htp.table_header('Incidents', 'align=right');
   HTP.tablerowclose;

   i:=0;
   FOR incidents_rec IN incidents_cur
   LOOP
       IF MOD (i, 2) = 0 THEN
            l_cell_color := vv_htp.c_list_color1;
       ELSE
            l_cell_color := vv_htp.c_list_color2;
       END IF;

       i := i + 1;

       if to_char(incidents_rec.incident_date, 'DD-MON-YYYY') = expand_date then
          l_expand:= true;
       else
          l_expand:= false;
       end if;

       HTP.tablerowopen;
         if l_expand then
            htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
            || 'vvcs_incidents',
            htf.img('/media/aftreeop.gif'), 'current'   -- Display TAG
            ), CATTRIBUTES=>'align=center');
--          ), CATTRIBUTES=>'bgcolor=' || vv_htp.C_DEFAULT_BG_COLOR || ' align=center');
         else
            htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
            || 'vvcs_incidents?expand_date=' || to_char(incidents_rec.incident_date, 'DD-MON-YYYY')
            || '#current',
            htf.img('/media/aftreecl.gif')
            ), CATTRIBUTES=>'align=center');
--          ), CATTRIBUTES=>'bgcolor=' || vv_htp.C_DEFAULT_BG_COLOR || ' align=center');
         end if;

--      vv_htp.cell_filler('');
        vv_htp.table_data(to_char(incidents_rec.incident_date, 'DD-MON-YYYY'),  l_cell_color);
        vv_htp.table_data(incidents_rec.incidents, l_cell_color, 'align=right');
       HTP.tablerowclose;

       if l_expand then
          HTP.tablerowopen;
          htp.print('<td colspan=3>');

             HTP.tableopen ('width=100%');
             HTP.tablerowopen;
              vv_htp.cell_filler('width=4%');
              vv_htp.cell_filler('width=10%');
              vv_htp.sub_table_header('Incident Type');
              vv_htp.sub_table_header('Incidents', 'align=right');
              vv_htp.sub_table_header('% of Total','align=right');
             HTP.tablerowclose;

             j:=0;
             for inc_types_rec in incident_types_cur(incidents_rec.incident_date) loop
                if mod(j,2) = 0 then
                   l_cell_color := vv_htp.C_SUB_LIST_COLOR1;
                else
                   l_cell_color := vv_htp.C_SUB_LIST_COLOR2;
                end if;

                if inc_types_rec.incident_type_id = expand_type_id then
                   l_expand_type:= true;
                else
                   l_expand_type:= false;
                end if;

                -- Calculate Percent
                if incidents_rec.incidents <> 0 then
                  l_percent:=(inc_types_rec.incident_types * 100) / incidents_rec.incidents;
                else
                  l_percent:=0;
                end if;

                j:=j+1;
                htp.tableRowOpen;
                   vv_htp.cell_filler();

                   if l_expand_type then
                      htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
                      || 'vvcs_incidents?expand_date=' || to_char(incidents_rec.incident_date, 'DD-MON-YYYY'),
                      htf.img('/media/aftreeop.gif'), 'current'   -- Display TAG
                      ), CATTRIBUTES=>'align=right');
                   else
                      htp.tabledata( htf.anchor(vv_htp.C_BASE_URL
                      || 'vvcs_incidents?expand_date=' || to_char(incidents_rec.incident_date, 'DD-MON-YYYY')
                      || chr(38) || 'expand_type_id=' || inc_types_rec.incident_type_id 
                      || '#current',
                      htf.img('/media/aftreecl.gif')
                      ), CATTRIBUTES=>'align=right');
                   end if;

                   vv_htp.table_data(inc_types_rec.incident_type,  l_cell_color);
                   vv_htp.table_data(inc_types_rec.incident_types, l_cell_color, 'align=right');
                   vv_htp.table_data(to_char(l_percent, '999.0'),  l_cell_color, 'align=right');
                htp.tableRowClose;

                if l_expand_type then
                   HTP.tablerowopen;
                   htp.print('<td colspan=5>');

                     HTP.tableopen ('width=100%');
                     HTP.tablerowopen;
                       vv_htp.cell_filler('width=20%');
                       vv_htp.sub_table_header('Problem Code');
                       vv_htp.sub_table_header('Codes', 'align=right');
         --            vv_htp.sub_table_header('% of Total','align=right');
                       vv_htp.cell_filler('width=4%');
                     HTP.tablerowclose;

                     k:=0;
                     for inc_problem_rec in inc_problem_codes_cur(incidents_rec.incident_date
                                                               , inc_types_rec.incident_type_id) loop
                     /*{*/
                         if mod(k,2) = 0 then
                            l_cell_color := vv_htp.C_SUB_LIST_COLOR1;
                         else
                            l_cell_color := vv_htp.C_SUB_LIST_COLOR2;
                         end if;

                         k:=k+1;
                         htp.tableRowOpen;
                            vv_htp.cell_filler();
                            vv_htp.table_data(inc_problem_rec.problem_code,  l_cell_color);
                            vv_htp.table_data(inc_problem_rec.problem_codes, l_cell_color, 'align=right');
                            vv_htp.cell_filler();
                         htp.tableRowClose;
                     /*}*/
                     end loop;
                     htp.tableClose;

                  htp.print('</td>');
                  HTP.tablerowclose;

                end if; -- l_expand_type 

             end loop;

             IF j = 0 THEN
                vv_htp.cell_filler('');
                -- Make sure to use the number of columns displayed
                vv_htp.table_data('<b>No Incident Types Found</b>', vv_htp.C_SUB_LIST_COLOR1 , ' align="center" bgcolor="'
	                || '" colspan="4"');
             END IF;

             htp.tableClose;

          htp.print('</td>');
          HTP.tablerowclose;
       end if;

   end loop;

   if i = 0 then
      vv_htp.create_blank_row ('3');
   end if;  

   HTP.tableclose;
  
   htp.br; 
   htp.br; 

   vv_htp.create_footer;

   HTP.bodyclose;

   end if;  -- sessionValidate
   /*}*/
   HTP.htmlclose;

END; -- Procedure VVCS_INCIDENTS
/
show errors
